@@ -4,6 +4,8 @@ from hoerapi.errors import MissingAttributeError, InvalidDataError
 def parser_list(clazz, data):
     if isinstance(data, list):
         return [parser_object(clazz, item) for item in data]
+    elif data is None:
+        return []
     else:
         raise InvalidDataError('not an array')
 
